magneticalc.QtWidgets2.QSpinBox2.QSpinBox2

# ``magneticalc`.`QtWidgets2`.`QSpinBox2`.`QSpinBox2``

class documentation

`class QSpinBox2(QSpinBox):`

Constructor: `QSpinBox2(minimum, maximum, value, value_changed)`

View In Hierarchy

QSpinBox2 class.

Method | `__init__` | Initializes a spinbox.

def __init__(self, minimum: `int`, maximum: `int`, value: `int`, value_changed: `Callable`):

Initializes a spinbox.

Parameters
minimum: `int` | Minimum value
maximum: `int` | Maximum value
value: `int` | Initial value
value_changed: `Callable` | Value changed callback